@@ -1,8 +1,10 @@
 import logging
 
-from .client import Client
-from .version import __version__
+import pkg_resources
 
+from .client import Client
+
+__version__ = pkg_resources.get_distribution("pytd").version
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.StreamHandler())
 logger.setLevel(logging.INFO)
